is_include_required_category

Function is_include_required_category 

pub fn is_include_required_category(id: &str) -> bool
Whether a security.categories id is include-required, i.e. it stays off even when no include list is set and fires only when named in categories.include. Both the standalone hardcoded-secret detector and the secret-to-network catalogue category are include-required.