pub fn enable_security_rules(config: &mut ResolvedConfig)Expand description
Enable the advisory security rules for a dedicated security-aware surface.
Explicit user severities are preserved. Only the default off state is
promoted to warn, so fallow security and the viz Security lens surface
candidates without overriding a deliberate configuration.